@@ -15,7 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from arjuna.tpi.engine.data.record import DataRecord
+from arjuna.tpi.data.record import DataRecord
 
 class DummyDataRecord(DataRecord):
     
