@@ -18,80 +18,6 @@
 from itertools import cycle
 from py.xml import html, raw
 
-ARJUNA_JS = '''
-function openModal(event){
-    var source = event.target || event.srcElement;
-    var modal = document.getElementById("modal-packet");
-    modal.style.display = "block";
-    var req = document.getElementById("modal-packet-request");
-    req.innerHTML = ""
-    var h3_req = document.createElement("h3");
-    h3_req.innerHTML = "Request"
-    req.appendChild(h3_req)
-    req.appendChild(document.createTextNode(source.getAttribute("data-request")))
-
-    var res = document.getElementById("modal-packet-response");
-    res.innerHTML = ""
-    var h3_res = document.createElement("h3");
-    h3_res.innerHTML = "Response"
-    req.appendChild(h3_res)
-    res.appendChild(document.createTextNode(source.getAttribute("data-response")))
-    var span = document.getElementById(source.id + "modal-packet-span");
-    span.onclick = function() {
-        modal.style.display = "none";
-    }
-
-    window.onclick = function(event) {
-        if (event.target == modal) {
-            modal.style.display = "none";
-        }
-    }
-
-}
-
-function openModalImage(event){
-    var img_link = event.target || event.srcElement;
-    var modal = document.getElementById("modal-image");
-    var modal_image = document.getElementById("modal-image-content");
-    modal.style.display = "block";
-    modal_image.src = img_link.src;
-    var span = document.getElementById("modal-image-span");
-    span.onclick = function() {
-        modal.style.display = "none";
-    }
-
-    window.onclick = function(event) {
-        if (event.target == modal) {
-            modal.style.display = "none";
-        }
-    }
-}
-'''
-
-IMG_SPAN ='''
-
-<!-- The Network Packet Modal -->
-<div id="modal-packet" class="modal">
-
-  <!-- Modal content -->
-  <div class="modal-content">
-    <span id="modal-packet-span" class="close">&times;</span>
-    <div class="linebreaks"><p id="modal-packet-request"></p><p id="modal-packet-response"></p>
-    </div>
-  </div>
-
-</div>
-
-<!-- The Modal -->
-<div id="modal-image" class="modal">
-<div class="modal-content">
-  <span id="modal-image-span" class="close">&times;</span>
-  <img id="modal-image-content" class="modal-content">
-  <div id="caption"></div>
-  </div>
-</div>
-'''
-
 class PytestHooks:
     '''
         Easy hooks to be used in **pytest** configuration file: **conftest.py** placed under **<Project_Root_Dir/test** directory in test project.
@@ -117,14 +43,14 @@ class PytestHooks:
         return cls._get_plugin(item, 'html')
 
     @classmethod
-    def _get_screen_shooter(cls, item):
+    def _get_protocol_object(cls, item, name):
         try:
-            return getattr(item.function, "screen_shooter")
+            return getattr(item.function, name)
         except:
             try:
-                return getattr(item.module, "screen_shooter")
+                return getattr(item.module, name)
             except:
-                return getattr(item.session, "screen_shooter")
+                return getattr(item.session, name)
 
     @classmethod
     def prepare_result(cls, result):
@@ -144,11 +70,14 @@ class PytestHooks:
 
     @classmethod
     def inject_arjuna_js(cls, prefix):
-        prefix += [html.script(raw(ARJUNA_JS))]
-        prefix += [raw(IMG_SPAN)]
+        from arjuna import C
+        with open(C("arjuna.root.dir") + "/arjuna/res/arjuna.js", "r") as f:
+            prefix += [html.script(raw(f.read()))]
+        with open(C("arjuna.root.dir") + "/arjuna/res/arjuna.html", "r") as f:
+            prefix += [raw(f.read())]
 
     @classmethod
-    def enhance_reports(cls, item, result, *, ignore_passed=True, ignore_fixtures=False):
+    def enhance_reports(cls, item, result):
         '''
             Automatically add screenshot to HTML Report File.
 
@@ -158,10 +87,6 @@ class PytestHooks:
                 item: **pytest**'s Item object
                 result: **pytest**'s TestReport object.
 
-            Keyword Arguments:
-                ignore_passed: (Optional) If set to True, screenshot is taken when the test function completes. Default is True.
-                ignore_fixtures: (Optional) If set to True, screenshot is not taken for test fixture functions. Default is False.
-
             Note:
                 - For taking the screenshot, it does a look up for a **screen_shooter** attribute in the object spaces in following order:
                     - Function Space
@@ -174,9 +99,20 @@ class PytestHooks:
         '''
 
         try:
+            from arjuna import Arjuna, ArjunaOption, log_debug
+            ignore_passed_for_screenshots = not Arjuna.get_config().value(ArjunaOption.REPORT_SCREENSHOTS_ALWAYS)
+            ignore_passed_for_network = not Arjuna.get_config().value(ArjunaOption.REPORT_NETWORK_ALWAYS)
+
+            include_images = True
+            include_network = True
+
             html_plugin = cls._get_html_report_plugin(item)
             pytest_html = html_plugin
             report = result.get_result()
+
+            log_debug("Node ID: {}".format(report.nodeid), contexts="report")
+            log_debug("Stage: {}".format(report.when), contexts="report")
+
             extra = getattr(report, 'extra', [])
 
             # if ignore_fixtures:
@@ -185,35 +121,60 @@ class PytestHooks:
 
             xfail = hasattr(report, 'wasxfail')
 
-            if ignore_passed and report.passed:
-                pass
+            if ignore_passed_for_screenshots and report.passed:
+                include_images = False
             else:
                 # if (report.skipped and xfail) and (report.failed and not xfail):
                     # extra.append(pytest_html.extras.url(app.url))
                 try:
-                    screen_shooter = cls._get_screen_shooter(item)
+                    screen_shooter = cls._get_protocol_object(item, "screen_shooter")
                 except AttributeError:
                     pass
                 else:
                     screen_shooter.take_screenshot(prefix=report.nodeid)
-            
-            from arjuna import Arjuna
-            test_container = Arjuna.get_report_metadata()
-            if test_container.has_content():
-                extra.append(pytest_html.extras.html(test_container.as_report_html()))
+
+            log_debug("Attempting to get network_recorder from request", contexts="report")
+            try:
+                network_recorder = cls._get_protocol_object(item, "network_recorder")
+            except AttributeError as e:
+                log_debug("No network_recorder", contexts="report")
+            else:
+                try:
+                    log_debug("Registering traffic", contexts="report")
+                    network_recorder.register()
+                    log_debug("Traffic registered.", contexts="report")
+                except Exception as e:
+                    log_debug("Exception in registering network traffic: " + str(e), contexts="report")
+
+            if ignore_passed_for_network and report.passed:
+                include_network = False
+
+            log_debug("Include images {}".format(include_images), contexts="report")
+            log_debug("Include network {}".format(include_network), contexts="report")
+
+            # When this place is reached by a resource that failed/erred or a test (irrespective of result)
+            if (report.when in {"setup", "teardown"} and not report.passed) or report.when =="call":
+                test_container = Arjuna.get_report_metadata()
+                if test_container.has_content():
+                    log_debug("Extra Content Found for HTML Report", contexts="report")
+                    extra_html = test_container.as_report_html(include_images=include_images, include_network=include_network)
+                    if extra_html:
+                        extra.append(pytest_html.extras.html(extra_html))
+                        report.extra = extra
 
             # For fixtures with errors, failures, clean the resources.
             if report.when in {"setup", "teardown"}:
                 if not report.passed:
+                    log_debug("Clearing report extras.", contexts="report")
                     Arjuna.get_report_metadata().clear()
             else:
-                Arjuna.get_report_metadata().clear()
+                log_debug("Clearing report extras.", contexts="report")
+                Arjuna.get_report_metadata().clear()    
             
-            report.extra = extra
         except Exception as e:
             raise
             from arjuna import log_warning
-            log_warning("Error in enhance_reports hook: " + str(e))
+            log_warning("Error in enhance_reports hook: " + str(e), contexts="report")
 
 
     @classmethod
@@ -237,13 +198,13 @@ class PytestHooks:
 
         from arjuna import Arjuna, ArjunaOption, log_debug, C
         from arjuna.tpi.engine.data_markup import record
-        log_debug("{} {}".format(metafunc.function, metafunc.fixturenames))
+        log_debug("{} {}".format(metafunc.function, metafunc.fixturenames), contexts="resource")
 
         group_params = Arjuna.get_group_params()
         conf = None
         m = metafunc.function.__module__
         group = record(**group_params).build(context='Group').all_records[0]
-        log_debug("Parameterizing distributor for module: {} with group: {}".format(m, group))
+        log_debug("Parameterizing distributor for module: {} with group: {}".format(m, group), contexts="resource")
         metafunc.parametrize("group", argvalues=[group], ids=["G"], indirect=True)
 
     @classmethod
