@@ -16,6 +16,7 @@
 # limitations under the License.
 
 import os
+import platform
 
 import pytest
 
@@ -106,7 +107,11 @@ class TestGroup:
         pytest_ini_path = res_path + "/pytest.ini"
 
         # -s is to print to console.
-        self.__pytest_args = ["-c", pytest_ini_path, "--rootdir", self.__project_dir, "--no-print-logs", "--show-capture", "all", "--disable-warnings", "-rxX", "--css", self.__css_path] # 
+        self.__pytest_args = ["-c", pytest_ini_path, "--rootdir", self.__project_dir, "--disable-warnings", "-rxX", "--css", self.__css_path]
+        if platform.system().casefold() == "Windows".casefold() :
+            self.__pytest_args.extend(["--capture", "no"])
+        else:
+            self.__pytest_args.extend(["--no-print-logs", "--show-capture", "all"])
         self.__test_args = []
         self.__load_tests(rules=self.__rules)
         self.__load_meta_args()
