@@ -16,8 +16,8 @@
 # limitations under the License.
 
 from functools import partial
-from arjuna.tpi.exceptions import *
-from arjuna.core.exceptions import *
+from arjuna.tpi.error import *
+from arjuna.core.error import *
 from arjuna.tpi.guiauto.meta.locator import GuiWidgetLocator
 
 class GuiEmdFinder:
@@ -37,8 +37,8 @@ class GuiFinder:
 
     def locate(self, locator):
         from arjuna import log_debug
-        from arjuna.core.exceptions import ArjunaTimeoutError
-        from arjuna.tpi.exceptions import GuiWidgetNotPresentError
+        from arjuna.core.error import ArjunaTimeoutError
+        from arjuna.tpi.error import GuiWidgetNotPresentError
         
         wmd = locator._as_wmd()
         log_debug("Finding element with wmd: {}.".format(wmd))
@@ -81,8 +81,8 @@ class GuiElementFinder:
 
     def locate(self, locator):
         from arjuna import log_debug
-        from arjuna.core.exceptions import ArjunaTimeoutError
-        from arjuna.tpi.exceptions import GuiWidgetNotPresentError
+        from arjuna.core.error import ArjunaTimeoutError
+        from arjuna.tpi.error import GuiWidgetNotPresentError
 
         wmd = locator._as_wmd()
         log_debug("Finding element with wmd: {}.".format(wmd))
