@@ -217,7 +217,7 @@ class TestDecoratorError(Exception):
         super().__init__(f"There is an error in @test decoratior for {func_qual_name}. {msg}")
 
 
-class HttpUnexpectedStatusCode(Exception):
+class HttpUnexpectedStatusCodeError(Exception):
     '''
         Raised when the HTTP status code for a request does not match expected status code(s).
     '''
@@ -234,3 +234,59 @@ class HttpUnexpectedStatusCode(Exception):
     @property
     def response(self):
         return self.__response
+
+class HttpRequestCreationError(Exception):
+    '''
+    Raised when there is an error in creating an HTTP request.
+    '''
+
+    def __init__(self, msg):
+        super().__init__(f"Error in creating HTTP Request. {msg}")
+
+class HttpConnectError(Exception):
+    '''
+    Raised when there is a connection error.
+    '''
+
+    def __init__(self, request, msg):
+        super().__init__(f"Connection Error: {request.method} {request.url}. {msg}")
+        self.__request = request
+
+    @property
+    def request(self):
+        return self.__request
+
+
+class HttpSendError(Exception):
+    '''
+        Raised when there is an error in sending an HTTP request.
+    '''
+
+    def __init__(self, request, response, msg):
+        super().__init__(f"Error in HTTP Request: {request.method} {request.url}. {msg}")
+        self.__request = request
+        self.__response = response
+
+    @property
+    def request(self):
+        return self.__request
+
+    @property
+    def response(self):
+        return self.__response
+
+class DisallowedArjunaOptionError(Exception):
+    '''
+        Raised when there is an attempt to set an ArjunOption value in a configuration stage, where it is not allowed to override the value.
+    '''
+
+    def __init__(self, stage, option):
+        super().__init__("Option {} is not allowed in a {} configuration.".format(option, stage.name.title()))
+
+
+class ArjunaOptionValidationError(Exception):
+
+    def __init__(self, option, name, validator):
+        super().__init__(
+            "Config option value <{}>(type:{}) for <{}> option did not pass the validation check: [{}]".format(
+                    option, type(option), name, validator))
\ No newline at end of file
