@@ -20,9 +20,9 @@ import os
 from arjuna.tpi.tracker import track
 from .base import GuiSource
 from .content import GuiSourceContent
-from arjuna.tpi.helper.xml import XmlNode
+from arjuna.tpi.parser.xml import XmlNode
 
-@track("debug")
+@track("trace")
 class GuiMultiElementSource(GuiSource):
     '''
         A combined source of all GuiElements in a GuiMultiElement.
@@ -42,7 +42,7 @@ class GuiMultiElementSource(GuiSource):
         return os.linesep.join([e.source.content.inner for e in self.__instances])
 
     def __get_text_content(self):
-        return os.linesep.join([e.source.content.root for e in self.__instances])
+        return os.linesep.join([e.source.content.text for e in self.__instances])
 
     def __get_root_content(self):
         return os.linesep.join([e.source.content.root for e in self.__instances])
